@@ -5,12 +5,12 @@
 
 /* Package information */
 #define PACKAGE           "task"
-#define VERSION           "2.4.2"
+#define VERSION           "2.4.4"
 #define PACKAGE_BUGREPORT "support@taskwarrior.org"
 #define PACKAGE_NAME      "task"
 #define PACKAGE_TARNAME   "task"
-#define PACKAGE_VERSION   "2.4.2"
-#define PACKAGE_STRING    "task 2.4.2"
+#define PACKAGE_VERSION   "2.4.4"
+#define PACKAGE_STRING    "task 2.4.4"
 
 #define CMAKE_BUILD_TYPE  ""
 
@@ -27,6 +27,7 @@
 #define LANGUAGE_POR_PRT 6
 #define LANGUAGE_EPO_RUS 7
 #define LANGUAGE_POL_POL 8
+#define LANGUAGE_JPN_JPN 9
 
 /* git information */
 #define HAVE_COMMIT
@@ -51,12 +52,6 @@
 /* Found the GnuTLS library */
 #define HAVE_LIBGNUTLS
 
-/* Found the Readline library */
-/* #undef HAVE_READLINE */
-
-/* Found the pthread library */
-/* #undef HAVE_LIBPTHREAD */
-
 /* Found tm_gmtoff */
 #define HAVE_TM_GMTOFF
 
