@@ -220,16 +220,14 @@ const std::string A::dump () const
 // Static method.
 void CLI::getOverride (int argc, const char** argv, std::string& home, File& rc)
 {
-  bool terminated = false;
   for (int i = 0; i < argc; ++i)
   {
     std::string raw = argv[i];
 
     if (raw == "--")
-      terminated = true;
+      return;
 
-    if (! terminated      &&
-        raw.length () > 3 &&
+    if (raw.length () > 3 &&
         raw.substr (0, 3) == "rc:")
     {
       rc = raw.substr (3);
@@ -351,7 +349,6 @@ void CLI::initialize (int argc, const char** argv)
   _terminated = false;
 
   _original_args.push_back (argv[0]);
-  bool terminated = false;
   for (int i = 1; i < argc; ++i)
   {
     if (isTerminator (argv[i]))
@@ -379,10 +376,9 @@ void CLI::addContextFilter ()
 {
   // Detect if any context is set, and bail out if not
   std::string contextName = context.config.get ("context");
-
   if (contextName == "")
   {
-    context.debug("No context applied.");
+    context.debug ("No context applied.");
     return;
   }
 
@@ -392,35 +388,35 @@ void CLI::addContextFilter ()
     std::vector <A>::const_iterator a;
     for (a = _args.begin (); a != _args.end (); ++a)
     {
+      // TODO This looks wrong.
       if (a->hasTag ("FILTER") &&
           a->hasTag ("ATTRIBUTE") &&
           ! a->hasTag ("TERMINATED") &&
           ! a->hasTag ("WORD") &&
           (a->attribute ("raw") == "id" || a->attribute ("raw") == "uuid"))
       {
-        context.debug(format("UUID/ID lexeme found '{1}', not applying context.", a->attribute ("raw")));
+        context.debug (format ("UUID/ID lexeme found '{1}', not applying context.", a->attribute ("raw")));
         return;
       }
     }
   }
 
   // Apply context
-  context.debug("Applying context: " + contextName);
+  context.debug ("Applying context: " + contextName);
   std::string contextFilter = context.config.get ("context." + contextName);
 
   if (contextFilter == "")
-    context.debug("Context '" + contextName + "' not defined!");
+    context.debug ("Context '" + contextName + "' not defined.");
   else
   {
-    addRawFilter("( " + contextFilter + " )");
+    addRawFilter ("( " + contextFilter + " )");
     if (context.verbose ("context"))
-      context.footnote (format("Context '{1}' set. Use 'task context none' to remove.", contextName));
+      context.footnote (format ("Context '{1}' set. Use 'task context none' to remove.", contextName));
   }
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 // Process raw string into parsed filter.
-//
 void CLI::addRawFilter (const std::string& arg)
 {
   std::string lexeme;
@@ -446,7 +442,7 @@ void CLI::analyze (bool parse /* = true */, bool strict /* = false */)
   // For propagation.
   _strict = strict;
 
-  for (int i = 0; i < _original_args.size (); ++i)
+  for (unsigned int i = 0; i < _original_args.size (); ++i)
   {
     std::string raw = _original_args[i];
     A a ("arg", raw);
@@ -692,7 +688,7 @@ const std::string CLI::dump (const std::string& title /* = "CLI Parser" */) cons
 //       be lexed from those that need to be left alone.
 //
 // Either the arg is appended to _original_args intact, or the lexemes are.
-void CLI::addArg (const std::string& arg)
+void CLI::addArg (const std::string& arg, Lexer::Type type /* = Lexer::Type::word */)
 {
   std::string raw = trim (arg);
 
@@ -718,8 +714,8 @@ void CLI::addArg (const std::string& arg)
     _original_args.push_back (raw);
   }
 
-  // The argument may require lexing.  Lex anyway, and analyze before comitting
-  // that.
+  // The argument may require lexing. Lex anyway, and analyze before comitting
+  // to that.
   else
   {
     // Lex each remaining argument.  The apply a series of disqualifying tests
@@ -730,7 +726,7 @@ void CLI::addArg (const std::string& arg)
     Lexer lex (raw);
     lex.ambiguity (false);
 
-    std::vector <std::pair <std::string, Lexer::Type> > lexemes;
+    std::vector <std::pair <std::string, Lexer::Type>> lexemes;
     while (lex.token (lexeme, type))
       lexemes.push_back (std::pair <std::string, Lexer::Type> (lexeme, type));
 
@@ -746,7 +742,7 @@ void CLI::addArg (const std::string& arg)
     {
       // How often have I said to you that when you have eliminated the
       // impossible, whatever remains, however improbable, must be the truth?
-      std::vector <std::pair <std::string, Lexer::Type> >::iterator l;
+      std::vector <std::pair <std::string, Lexer::Type>>::iterator l;
       for (l = lexemes.begin (); l != lexemes.end (); ++l)
         _original_args.push_back (l->first);
     }
@@ -778,9 +774,7 @@ void CLI::aliasExpansion ()
       {
         if (_aliases.find (raw) != _aliases.end ())
         {
-          std::vector <std::string> lexed;
-          Lexer::token_split (lexed, _aliases[raw]);
-
+          std::vector <std::string> lexed = Lexer::split (_aliases[raw]);
           std::vector <std::string>::iterator l;
           for (l = lexed.begin (); l != lexed.end (); ++l)
           {
@@ -916,7 +910,7 @@ void CLI::categorize ()
       a->tag ("MODIFICATION");
 
       // If the argument contains a space, it was quoted.  Record that.
-      if (! noSpaces (raw))
+      if (! Lexer::isOneWord (raw))
         a->tag ("QUOTED");
 
       changes = true;
@@ -926,7 +920,7 @@ void CLI::categorize ()
       a->tag ("FILTER");
 
       // If the argument contains a space, it was quoted.  Record that.
-      if (! noSpaces (raw))
+      if (! Lexer::isOneWord (raw))
         a->tag ("QUOTED");
 
       changes = true;
@@ -1240,7 +1234,7 @@ void CLI::desugarFilterAttributeModifiers ()
                 }
                 else if (modifier == "isnt" || modifier == "not")
                 {
-                  op.attribute ("raw", "!=");
+                  op.attribute ("raw", "!==");
                   rhs.attribute ("raw", "'" + value + "'");
                   rhs.tag ("LITERAL");
                 }
@@ -1389,14 +1383,12 @@ void CLI::findIDs ()
   {
     if (a->hasTag ("FILTER"))
     {
-      bool found = false;
-
       // IDs have a limited character set.
       std::string raw = a->attribute ("raw");
       if (raw.find_first_not_of ("0123456789,-") == std::string::npos)
       {
         // Container for min/max ID ranges.
-        std::vector <std::pair <int, int> > ranges;
+        std::vector <std::pair <int, int>> ranges;
 
         // Split the ID list into elements.
         std::vector <std::string> elements;
@@ -1412,7 +1404,7 @@ void CLI::findIDs ()
 
           if (terms.size () == 1)
           {
-            if (! digitsOnly (terms[0]))
+            if (! Lexer::isAllDigits (terms[0]))
             {
               is_an_id = false;
               break;
@@ -1433,8 +1425,8 @@ void CLI::findIDs ()
           }
           else if (terms.size () == 2)
           {
-            if (! digitsOnly (terms[0]) ||
-                ! digitsOnly (terms[1]))
+            if (! Lexer::isAllDigits (terms[0]) ||
+                ! Lexer::isAllDigits (terms[1]))
             {
               is_an_id = false;
               break;
@@ -1475,7 +1467,7 @@ void CLI::findIDs ()
           a->tag ("ID");
 
           // Save the ranges.
-          std::vector <std::pair <int, int> >::iterator r;
+          std::vector <std::pair <int, int>>::iterator r;
           for (r = ranges.begin (); r != ranges.end (); ++r)
             _id_ranges.push_back (*r);
         }
@@ -1584,7 +1576,7 @@ void CLI::insertIDExpr ()
         reconstructed.push_back (openParen);
 
         // Add all ID ranges.
-        std::vector <std::pair <int, int> >::iterator r;
+        std::vector <std::pair <int, int>>::iterator r;
         for (r = _id_ranges.begin (); r != _id_ranges.end (); ++r)
         {
           if (r != _id_ranges.begin ())
@@ -1879,8 +1871,7 @@ void CLI::injectDefaults ()
       if (defaultCommand != "")
       {
         // Split the defaultCommand into separate args.
-        std::vector <std::string> tokens;
-        Lexer::token_split (tokens, defaultCommand);
+        std::vector <std::string> tokens = Lexer::split (defaultCommand);
 
         // Modify _args to be:   <args0> [<def0> ...] <args1> [...]
         std::vector <A> reconstructed;
@@ -2274,7 +2265,7 @@ bool CLI::isIDSequence (const std::string& raw) const
 ////////////////////////////////////////////////////////////////////////////////
 bool CLI::isID (const std::string& raw) const
 {
-  return digitsOnly (raw);
+  return Lexer::isAllDigits (raw);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -2368,11 +2359,11 @@ bool CLI::isName (const std::string& raw) const
 {
   if (raw != "")
   {
-    for (int i = 0; i < raw.length (); ++i)
+    for (unsigned int i = 0; i < raw.length (); ++i)
     {
-      if (i == 0 && ! Lexer::is_ident_start (raw[i]))
+      if (i == 0 && ! Lexer::isIdentifierStart (raw[i]))
         return false;
-      else if (! Lexer::is_ident (raw[i]))
+      else if (! Lexer::isIdentifierNext (raw[i]))
         return false;
     }
 
@@ -2384,19 +2375,19 @@ bool CLI::isName (const std::string& raw) const
 
 ////////////////////////////////////////////////////////////////////////////////
 bool CLI::disqualifyInsufficientTerms (
-  const std::vector <std::pair <std::string, Lexer::Type> >& lexemes) const
+  const std::vector <std::pair <std::string, Lexer::Type>>& lexemes) const
 {
   return lexemes.size () < 3 ? true : false;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 bool CLI::disqualifyNoOps (
-  const std::vector <std::pair <std::string, Lexer::Type> >& lexemes) const
+  const std::vector <std::pair <std::string, Lexer::Type>>& lexemes) const
 {
   bool foundOP = false;
-  std::vector <std::pair <std::string, Lexer::Type> >::const_iterator l;
+  std::vector <std::pair <std::string, Lexer::Type>>::const_iterator l;
   for (l = lexemes.begin (); l != lexemes.end (); ++l)
-    if (l->second == Lexer::typeOperator)
+    if (l->second == Lexer::Type::op)
       foundOP = true;
 
   return ! foundOP;
@@ -2404,16 +2395,16 @@ bool CLI::disqualifyNoOps (
 
 ////////////////////////////////////////////////////////////////////////////////
 bool CLI::disqualifyOnlyParenOps (
-  const std::vector <std::pair <std::string, Lexer::Type> >& lexemes) const
+  const std::vector <std::pair <std::string, Lexer::Type>>& lexemes) const
 {
   int opCount      = 0;
   int opSugarCount = 0;
   int opParenCount = 0;
 
-  std::vector <std::pair <std::string, Lexer::Type> >::const_iterator l;
+  std::vector <std::pair <std::string, Lexer::Type>>::const_iterator l;
   for (l = lexemes.begin (); l != lexemes.end (); ++l)
   {
-    if (l->second == Lexer::typeOperator)
+    if (l->second == Lexer::Type::op)
     {
       ++opCount;
 
@@ -2440,7 +2431,7 @@ bool CLI::disqualifyOnlyParenOps (
 // as there are no operators in between, which includes syntactic sugar that
 // hides operators.
 bool CLI::disqualifyFirstLastBinary (
-  const std::vector <std::pair <std::string, Lexer::Type> >& lexemes) const
+  const std::vector <std::pair <std::string, Lexer::Type>>& lexemes) const
 {
   bool firstBinary = false;
   bool lastBinary  = false;
@@ -2459,7 +2450,7 @@ bool CLI::disqualifyFirstLastBinary (
 ////////////////////////////////////////////////////////////////////////////////
 // Disqualify terms when there operators hidden by syntactic sugar.
 bool CLI::disqualifySugarFree (
-  const std::vector <std::pair <std::string, Lexer::Type> >& lexemes) const
+  const std::vector <std::pair <std::string, Lexer::Type>>& lexemes) const
 {
   bool sugared = true;
   for (unsigned int i = 1; i < lexemes.size () - 1; ++i)
