@@ -65,33 +65,6 @@ static const char* modifierNames[] =
 
 #define NUM_MODIFIER_NAMES       (sizeof (modifierNames) / sizeof (modifierNames[0]))
 
-static const char* attributeNames[] =
-{
-  "depends",
-  "description",
-  "due",
-  "end",
-  "entry",
-  "id",
-  "imask",
-  "mask",
-  "modified",
-  "parent",
-  "priority",
-  "project",
-  "recur",
-  "scheduled",
-  "start",
-  "status",
-  "tags",
-  "until",
-  "urgency",
-  "uuid",
-  "wait"
-};
-
-#define NUM_ATTRIBUTE_NAMES       (sizeof (attributeNames) / sizeof (attributeNames[0]))
-
 ////////////////////////////////////////////////////////////////////////////////
 Context::Context ()
 : rc_file ("~/.taskrc")
@@ -101,6 +74,7 @@ Context::Context ()
 , dom ()
 , determine_color_use (true)
 , use_color (true)
+, run_gc (true)
 , verbosity_legacy (false)
 , terminal_width (0)
 , terminal_height (0)
@@ -478,7 +452,14 @@ int Context::dispatch (std::string &out)
     // GC is invoked prior to running any command that displays task IDs, if
     // possible.
     if (c->displays_id () && !tdb2.read_only ())
+    {
+      run_gc = config.getBoolean ("gc");
       tdb2.gc ();
+    }
+    else
+    {
+      run_gc = false;
+    }
 
 /*
     // Only read-only commands can be run when TDB2 is read-only.
@@ -652,7 +633,6 @@ void Context::staticInitialization ()
   CLI::minimumMatchLength   = config.getInteger ("abbreviation.minimum");
 
   Task::defaultProject      = config.get ("default.project");
-  Task::defaultPriority     = config.get ("default.priority");
   Task::defaultDue          = config.get ("default.due");
 
   Task::searchCaseSensitive = Variant::searchCaseSensitive = config.getBoolean ("search.case.sensitive");
@@ -660,11 +640,25 @@ void Context::staticInitialization ()
   Lexer::dateFormat         = Variant::dateFormat          = config.get ("dateformat");
   Lexer::isoEnabled         = Variant::isoEnabled          = config.getBoolean ("date.iso");
 
+  Config::const_iterator rc;
+  for (rc = config.begin (); rc != config.end (); ++rc)
+  {
+    if (rc->first.substr (0, 4) == "uda." &&
+        rc->first.substr (rc->first.length () - 7, 7) == ".values")
+    {
+      std::string name = rc->first.substr (4, rc->first.length () - 7 - 4);
+      std::vector <std::string> values;
+      split (values, rc->second, ',');
+
+      for (auto r = values.rbegin(); r != values.rend (); ++r)
+        Task::customOrder[name].push_back (*r);
+    }
+  }
+
   std::map <std::string, Column*>::iterator i;
   for (i = columns.begin (); i != columns.end (); ++i)
     Task::attributes[i->first] = i->second->type ();
 
-  Task::urgencyPriorityCoefficient    = config.getReal ("urgency.priority.coefficient");
   Task::urgencyProjectCoefficient     = config.getReal ("urgency.project.coefficient");
   Task::urgencyActiveCoefficient      = config.getReal ("urgency.active.coefficient");
   Task::urgencyScheduledCoefficient   = config.getReal ("urgency.scheduled.coefficient");
