@@ -31,13 +31,13 @@
 #include <assert.h>
 #include <string.h>
 #include <stdlib.h>
-#include <ctype.h>
 #include <Nibbler.h>
 #include <Date.h>
 #include <Variant.h>
 #include <Dates.h>
 #include <text.h>
 #include <util.h>
+#include <utf8.h>
 #include <i18n.h>
 #include <Context.h>
 
@@ -823,7 +823,7 @@ void Date::operator++ (int)
 ////////////////////////////////////////////////////////////////////////////////
 bool Date::isEpoch (const std::string& input)
 {
-  if (digitsOnly (input) &&
+  if (Lexer::isAllDigits (input) &&
       input.length () <= 10 )
   {
     _t = (time_t) atoi (input.c_str ());
