@@ -102,7 +102,7 @@ bool TF2::get (int id, Task& task)
   // pending.data file, the task in question cannot appear earlier than line
   // (id - 1) in the file.  It can, however, appear significantly later because
   // it is not known how recent a GC operation was run.
-  for (int i = id - 1; i < _tasks.size (); ++i)
+  for (unsigned int i = id - 1; i < _tasks.size (); ++i)
   {
     if (_tasks[i].id == id)
     {
@@ -226,7 +226,7 @@ void TF2::commit ()
       if (_file.open ())
       {
         if (context.config.getBoolean ("locking"))
-          _file.waitForLock ();
+          _file.lock ();
 
         // Write out all the added tasks.
         std::vector <Task>::iterator task;
@@ -258,7 +258,7 @@ void TF2::commit ()
       if (_file.open ())
       {
         if (context.config.getBoolean ("locking"))
-          _file.waitForLock ();
+          _file.lock ();
 
         // Truncate the file and rewrite.
         _file.truncate ();
@@ -316,9 +316,15 @@ void TF2::load_tasks ()
       ++line_number;
       Task task (*i);
 
-      // Some tasks gets an ID.
+      // Some tasks get an ID.
       if (_has_ids)
-        task.id = context.tdb2.next_id ();
+      {
+        Task::status status = task.getStatus ();
+        // Completed / deleted tasks in pending.data get an ID if GC is off.
+        if (!context.run_gc ||
+            (status != Task::completed && status != Task::deleted))
+          task.id = context.tdb2.next_id ();
+      }
 
       _tasks.push_back (task);
 
@@ -352,7 +358,7 @@ void TF2::load_lines ()
   if (_file.open ())
   {
     if (context.config.getBoolean ("locking"))
-      _file.waitForLock ();
+      _file.lock ();
 
     _file.read (_lines);
     _file.close ();
@@ -462,9 +468,13 @@ void TF2::dependency_scan ()
         {
           if (right->get ("uuid") == *d)
           {
-            Task::status status = right->getStatus ();
-            if (status != Task::completed &&
-                status != Task::deleted)
+            // GC hasn't run yet, check both tasks for their current status
+            Task::status lstatus = left->getStatus ();
+            Task::status rstatus = right->getStatus ();
+            if (lstatus != Task::completed &&
+                lstatus != Task::deleted &&
+                rstatus != Task::completed &&
+                rstatus != Task::deleted)
             {
               left->is_blocked = true;
               right->is_blocking = true;
@@ -559,7 +569,9 @@ void TDB2::set_location (const std::string& location)
 void TDB2::add (Task& task, bool add_to_backlog /* = true */)
 {
   // Ensure the task is consistent, and provide defaults if necessary.
-  task.validate ();
+  // bool argument to validate() is "applyDefault". Pass add_to_backlog through
+  // in order to not apply defaults to synchronized tasks.
+  task.validate (add_to_backlog);
   std::string uuid = task.get ("uuid");
 
   // If the tasks are loaded, then verify that this uuid is not already in
@@ -578,7 +590,7 @@ void TDB2::add (Task& task, bool add_to_backlog /* = true */)
 ////////////////////////////////////////////////////////////////////////////////
 void TDB2::modify (Task& task, bool add_to_backlog /* = true */)
 {
-  // Ensure the task is consistent, and provide defaults if necessary.
+  // Ensure the task is consistent.
   task.validate (false);
   std::string uuid = task.get ("uuid");
 
@@ -598,7 +610,7 @@ void TDB2::update (
   const std::string& uuid,
   Task& task,
   const bool add_to_backlog,
-  const bool addition)
+  const bool addition /* = false */)
 {
   // Validate to add metadata.
   task.validate (false);
@@ -607,6 +619,13 @@ void TDB2::update (
   Task original;
   if (not addition && get (task.get ("uuid"), original))
   {
+    if (add_to_backlog)
+    {
+      // All locally modified tasks are timestamped, implicitly overwriting any
+      // changes the user or hooks tried to apply to the "modified" attribute.
+      task.setAsNow ("modified");
+    }
+
     // Update the task, wherever it is.
     if (!pending.modify_task (task))
       completed.modify_task (task);
