@@ -26,6 +26,7 @@
 
 #include <cmake.h>
 #include <sstream>
+#include <algorithm>
 #include <stdio.h>
 #include <math.h>
 #include <stdlib.h>
@@ -135,7 +136,7 @@ Variant::Variant (const char* value)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-Variant::Variant (const time_t value, const enum type new_type /*=type_date*/)
+Variant::Variant (const time_t value, const enum type new_type)
 : _type (new_type)
 , _bool (false)
 , _integer (0)
@@ -166,7 +167,7 @@ void Variant::source (const std::string& input)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::string Variant::source () const
+const std::string& Variant::source () const
 {
   return _source;
 }
@@ -314,19 +315,25 @@ bool Variant::operator< (const Variant& other) const
       return left._string < right._string;
 
     case type_string:
-      if (left.source () == "priority" || right.source () == "priority")
       {
-             if (left._string != "H" && right._string == "H") return true;
-        else if (left._string == "L" && right._string == "M") return true;
-        else if (left._string == ""  && right._string != "")  return true;
-        else                                                  return false;
-      }
-      else
-      {
-        if (left.trivial () || right.trivial ())
+        if (left._string == right._string)
           return false;
 
-        return left._string < right._string;
+        auto order = Task::customOrder.find (left.source ());
+        if (order != Task::customOrder.end ())
+        {
+          // Guaranteed to be found, because of ColUDA::validate ().
+          auto posLeft  = std::find (order->second.begin (), order->second.end (), left._string);
+          auto posRight = std::find (order->second.begin (), order->second.end (), right._string);
+          return posLeft < posRight;
+        }
+        else
+        {
+          if (left.trivial () || right.trivial ())
+            return false;
+
+          return left._string < right._string;
+        }
       }
 
     case type_date:
@@ -459,20 +466,25 @@ bool Variant::operator<= (const Variant& other) const
       return left._string <= right._string;
 
     case type_string:
-      if (left.source () == "priority" || right.source () == "priority")
       {
-             if (left._string        == right._string       ) return true;
-        else if (                       right._string == "H") return true;
-        else if (left._string == "L" && right._string == "M") return true;
-        else if (left._string == ""                         ) return true;
-        else                                                  return false;
-      }
-      else
-      {
-        if (left.trivial () || right.trivial ())
-          return false;
+        if (left._string == right._string)
+          return true;
 
-        return left._string <= right._string;
+        auto order = Task::customOrder.find (left.source ());
+        if (order != Task::customOrder.end ())
+        {
+          // Guaranteed to be found, because of ColUDA::validate ().
+          auto posLeft  = std::find (order->second.begin (), order->second.end (), left._string);
+          auto posRight = std::find (order->second.begin (), order->second.end (), right._string);
+          return posLeft <= posRight;
+        }
+        else
+        {
+          if (left.trivial () || right.trivial ())
+            return false;
+
+          return left._string <= right._string;
+        }
       }
 
     case type_date:
@@ -605,20 +617,27 @@ bool Variant::operator> (const Variant& other) const
       return left._string > right._string;
 
     case type_string:
-      if (left.source () == "priority" || right.source () == "priority")
       {
-             if (left._string == "H" && right._string != "H") return true;
-        else if (left._string == "M" && right._string == "L") return true;
-        else if (left._string != ""  && right._string == "")  return true;
-        else                                                  return false;
-      }
-      else
-      {
-        if (left.trivial () || right.trivial ())
+        if (left._string == right._string)
           return false;
 
-        return left._string> right._string;
+        auto order = Task::customOrder.find (left.source ());
+        if (order != Task::customOrder.end ())
+        {
+          // Guaranteed to be found, because of ColUDA::validate ().
+          auto posLeft  = std::find (order->second.begin (), order->second.end (), left._string);
+          auto posRight = std::find (order->second.begin (), order->second.end (), right._string);
+          return posLeft > posRight;
+        }
+        else
+        {
+          if (left.trivial () || right.trivial ())
+            return false;
+
+          return left._string > right._string;
+        }
       }
+
     case type_date:
       if (left.trivial () || right.trivial ())
         return false;
@@ -749,20 +768,25 @@ bool Variant::operator>= (const Variant& other) const
       return left._string >= right._string;
 
     case type_string:
-      if (left.source () == "priority" || right.source () == "priority")
       {
-             if (left._string        == right._string       ) return true;
-        else if (left._string == "H"                        ) return true;
-        else if (left._string == "M" && right._string == "L") return true;
-        else if (                       right._string == "" ) return true;
-        else                                                  return false;
-      }
-      else
-      {
-        if (left.trivial () || right.trivial ())
-          return false;
+        if (left._string == right._string)
+          return true;
 
-        return left._string >= right._string;
+        auto order = Task::customOrder.find (left.source ());
+        if (order != Task::customOrder.end ())
+        {
+          // Guaranteed to be found, because of ColUDA::validate ().
+          auto posLeft  = std::find (order->second.begin (), order->second.end (), left._string);
+          auto posRight = std::find (order->second.begin (), order->second.end (), right._string);
+          return posLeft >= posRight;
+        }
+        else
+        {
+          if (left.trivial () || right.trivial ())
+            return false;
+
+          return left._string >= right._string;
+        }
       }
 
     case type_date:
@@ -1964,6 +1988,8 @@ Variant::operator std::string () const
   case type_unknown:
     throw std::string (STRING_VARIANT_RENDER_UNK);
   }
+
+  return "";
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -2172,7 +2198,7 @@ double Variant::get_real () const
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::string Variant::get_string () const
+const std::string& Variant::get_string () const
 {
   return _string;
 }
