@@ -90,8 +90,8 @@ void ColumnRecur::measure (Task& task, unsigned int& minimum, unsigned int& maxi
     }
     else if (_style == "indicator")
     {
-      if (task.has (_name))
-        minimum = maximum = utf8_width (context.config.get ("recurrence.indicator"));
+      minimum = maximum = utf8_width (context.config.get ("recurrence.indicator"));
+      _fixed_width = true;
     }
     else
       throw format (STRING_COLUMN_BAD_FORMAT, _name, _style);
