@@ -172,13 +172,6 @@
 #define STRING_VARIANT_SQRT_NEG      "Cannot take the square root of a negative number."
 #define STRING_VARIANT_COERCE_UNK    "Cannot coerce data either to or from an unknown type"
 
-// Lexer
-//
-// These are errors generated at the lowest level of input analysis,
-// at the character level.
-#define STRING_LEX_IMMEDIATE_UNK     "Lexer start failure, unknown characters found immediately."
-#define STRING_LEX_TYPE_UNK          "Lexer cannot process an unknown token type."
-
 // Dates
 //
 // These are errors generated when parsing date values.
@@ -204,8 +197,6 @@
 #define STRING_COLUMN_LABEL_ADDED    "Added"
 #define STRING_COLUMN_LABEL_AGE      "Age"
 #define STRING_COLUMN_LABEL_ID       "ID"
-#define STRING_COLUMN_LABEL_PRI      "Pri"
-#define STRING_COLUMN_LABEL_PRIORITY "Priority"
 #define STRING_COLUMN_LABEL_PROJECT  "Project"
 #define STRING_COLUMN_LABEL_UNTIL    "Until"
 #define STRING_COLUMN_LABEL_WAIT     "Wait"
@@ -263,10 +254,10 @@
 // commands/Cmd*
 // USAGE strings are visible in 'task help'
 #define STRING_CMD_CONFLICT          "Custom report '{1}' conflicts with built-in task command."
-#define STRING_CMD_VERSION_USAGE     "Shows the taskwarrior version number"
-#define STRING_CMD_VERSION_USAGE2    "Shows only the taskwarrior version number"
-#define STRING_CMD_VERSION_MIT       "Taskwarrior may be copied only under the terms of the MIT license, which may be found in the taskwarrior source kit."
-#define STRING_CMD_VERSION_DOCS      "Documentation for taskwarrior can be found using 'man task', 'man taskrc', 'man task-color', 'man task-sync' or at http://taskwarrior.org"
+#define STRING_CMD_VERSION_USAGE     "Shows the Taskwarrior version number"
+#define STRING_CMD_VERSION_USAGE2    "Shows only the Taskwarrior version number"
+#define STRING_CMD_VERSION_MIT       "Taskwarrior may be copied only under the terms of the MIT license, which may be found in the Taskwarrior source kit."
+#define STRING_CMD_VERSION_DOCS      "Documentation for Taskwarrior can be found using 'man task', 'man taskrc', 'man task-color', 'man task-sync' or at http://taskwarrior.org"
 #define STRING_CMD_VERSION_BUILT     "{1} {2} built for "
 #define STRING_CMD_VERSION_UNKNOWN   "unknown"
 #define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2015 P. Beckingham, F. Hernandez."
@@ -341,7 +332,7 @@
 #define STRING_CMD_HISTORY_USAGE_A   "Shows a report of task history, by year"
 #define STRING_CMD_HISTORY_AVERAGE   "Average"
 #define STRING_CMD_HISTORY_LEGEND    "Legend: {1}, {2}, {3}"
-#define STRING_CMD_HISTORY_LEGEND_A  "Legend: + added, X completed, - deleted"
+#define STRING_CMD_HISTORY_LEGEND_A  "Legend: + Added, X Completed, - Deleted"
 #define STRING_CMD_GHISTORY_USAGE_M  "Shows a graphical report of task history, by month"
 #define STRING_CMD_GHISTORY_USAGE_A  "Shows a graphical report of task history, by year"
 #define STRING_CMD_GHISTORY_YEAR     "Year"
@@ -566,7 +557,7 @@
 #define STRING_CMD_CONTEXT_DEF_SUCC  "Context '{1}' defined."
 #define STRING_CMD_CONTEXT_DEF_FAIL  "Context '{1}' not defined."
 #define STRING_CMD_CONTEXT_DEF_USAG  "Both context name and its definition must be provided."
-#define STRING_CMD_CONTEXT_DEF_ABRT  "Context definiton aborted."
+#define STRING_CMD_CONTEXT_DEF_ABRT  "Context definition aborted."
 #define STRING_CMD_CONTEXT_DEF_ABRT2 "Filter validation failed: {1}"
 #define STRING_CMD_CONTEXT_DEF_CONF  "The filter '{1}' matches 0 pending tasks. Do you wish to continue?"
 #define STRING_CMD_CONTEXT_DEL_SUCC  "Context '{1}' deleted."
@@ -624,7 +615,7 @@
 #define STRING_CONFIG_DEPRECATED_VAR "Your .taskrc file contains variables that are deprecated:"
 
 // Context
-#define STRING_CONTEXT_CREATE_RC     "A configuration file could not be found in {1}\n\nWould you like a sample {2} created, so taskwarrior can proceed?"
+#define STRING_CONTEXT_CREATE_RC     "A configuration file could not be found in {1}\n\nWould you like a sample {2} created, so Taskwarrior can proceed?"
 #define STRING_CONTEXT_NEED_RC       "Cannot proceed without rc file."
 #define STRING_CONTEXT_RC_OVERRIDE   "TASKRC override: {1}"
 #define STRING_CONTEXT_DATA_OVERRIDE "TASKDATA override: {1}"
@@ -708,8 +699,6 @@
 
 #define STRING_EDIT_PROJECT_MOD      "Project modified."
 #define STRING_EDIT_PROJECT_DEL      "Project deleted."
-#define STRING_EDIT_PRIORITY_MOD     "Priority modified."
-#define STRING_EDIT_PRIORITY_DEL     "Priority deleted."
 #define STRING_EDIT_DESC_MOD         "Description modified."
 #define STRING_EDIT_DESC_REMOVE_ERR  "Cannot remove description."
 #define STRING_EDIT_ENTRY_REMOVE_ERR "Cannot remove creation date."
@@ -741,12 +730,12 @@
 #define STRING_EDIT_HEADER_1         "The 'task <id> edit' command allows you to modify all aspects of a task"
 #define STRING_EDIT_HEADER_2         "using a text editor.  Below is a representation of all the task details."
 #define STRING_EDIT_HEADER_3         "Modify what you wish, and when you save and quit your editor,"
-#define STRING_EDIT_HEADER_4         "taskwarrior will read this file, determine what changed, and apply"
+#define STRING_EDIT_HEADER_4         "Taskwarrior will read this file, determine what changed, and apply"
 #define STRING_EDIT_HEADER_5         "those changes.  If you exit your editor without saving or making"
-#define STRING_EDIT_HEADER_6         "modifications, taskwarrior will do nothing."
+#define STRING_EDIT_HEADER_6         "modifications, Taskwarrior will do nothing."
 
 #define STRING_EDIT_HEADER_7         "Lines that begin with # represent data you cannot change, like ID."
-#define STRING_EDIT_HEADER_8         "If you get too creative with your editing, taskwarrior will send you"
+#define STRING_EDIT_HEADER_8         "If you get too creative with your editing, Taskwarrior will send you"
 #define STRING_EDIT_HEADER_9         "back to the editor to try again."
 
 #define STRING_EDIT_HEADER_10        "Should you find yourself in an endless loop, re-editing the same file,"
@@ -863,7 +852,7 @@
 #define STRING_TASK_NO_FF1           "Taskwarrior no longer supports file format 1, originally used between 27 November 2006 and 31 December 2007."
 #define STRING_TASK_NO_FF2           "Taskwarrior no longer supports file format 2, originally used between 1 January 2008 and 12 April 2009."
 #define STRING_TASK_NO_FF3           "Taskwarrior no longer supports file format 3, originally used between 23 March 2009 and 16 May 2009."
-#define STRING_TASK_PARSE_UNREC_FF   "Unrecognized taskwarrior file format."
+#define STRING_TASK_PARSE_UNREC_FF   "Unrecognized Taskwarrior file format."
 #define STRING_TASK_DEPEND_ITSELF    "A task cannot be dependent on itself."
 #define STRING_TASK_DEPEND_MISS_CREA "Could not create a dependency on task {1} - not found."
 #define STRING_TASK_DEPEND_MISS_DEL  "Could not delete a dependency on task {1} - not found."
@@ -874,7 +863,6 @@
 #define STRING_TASK_VALID_BEFORE     "Warning: You have specified that the '{1}' date is after the '{2}' date."
 #define STRING_TASK_VALID_REC_DUE    "A recurring task must also have a 'due' date."
 #define STRING_TASK_VALID_RECUR      "The recurrence value '{1}' is not valid."
-#define STRING_TASK_VALID_PRIORITY   "Priority values may be 'H', 'M' or 'L', not '{1}'."
 #define STRING_TASK_SAFETY_VALVE     "This command has no filter, and will modify all tasks.  Are you sure?"
 #define STRING_TASK_SAFETY_FAIL      "Command prevented from running."
 #define STRING_TASK_SAFETY_ALLOW     "You did not specify a filter, and with the 'allow.empty.filter' value, no action is taken."
@@ -997,7 +985,7 @@
   "  task add \"quoted ' quote\"\n" \
   "  task add escaped \\' quote\n" \
   "\n" \
-  "The argument -- tells taskwarrior to treat all other args as description, even " \
+  "The argument -- tells Taskwarrior to treat all other args as description, even " \
   "if they would otherwise be attributes or tags:\n" \
   "  task add -- project:Home needs scheduling\n" \
   "\n" \
@@ -1006,7 +994,7 @@
   "\n"
 
 /*
-  To be included later, before the 'precendence' line.
+  To be included later, before the 'precedence' line.
 
   "  +  -                    Addition, subtraction\n" \
   "  !                       Inversion\n" \
@@ -1026,4 +1014,7 @@
 #define STRING_UTIL_KIBIBYTES        "KiB"
 #define STRING_UTIL_BYTES            "B"
 
+// Legacy
+#define STRING_LEGACY_PRIORITY       "Legacy attribute found.  Please change '{1}' to '{2}'."
+
 #endif
