@@ -172,13 +172,6 @@
 #define STRING_VARIANT_SQRT_NEG      "Ne peut pas calculer la racine carrée d'un nombre négatif."
 #define STRING_VARIANT_COERCE_UNK    "Cannot coerce data either to or from an unknown type"
 
-// Lexer
-//
-// These are errors generated at the lowest level of input analysis,
-// at the character level.
-#define STRING_LEX_IMMEDIATE_UNK     "Lexer start failure, unknown characters found immediately."
-#define STRING_LEX_TYPE_UNK          "Lexer cannot process and unknown token type."
-
 // Dates
 //
 // These are errors generated when parsing date values.
@@ -204,8 +197,6 @@
 #define STRING_COLUMN_LABEL_ADDED    "Ajoutée"
 #define STRING_COLUMN_LABEL_AGE      "Age"
 #define STRING_COLUMN_LABEL_ID       "ID"
-#define STRING_COLUMN_LABEL_PRI      "Pri"
-#define STRING_COLUMN_LABEL_PRIORITY "Priorité"
 #define STRING_COLUMN_LABEL_PROJECT  "Projet"
 #define STRING_COLUMN_LABEL_UNTIL    "Until"
 #define STRING_COLUMN_LABEL_WAIT     "Attente"
@@ -567,6 +558,7 @@
 #define STRING_CMD_CONTEXT_DEF_FAIL  "Context '{1}' not defined."
 #define STRING_CMD_CONTEXT_DEF_USAG  "Both context name and its definition must be provided."
 #define STRING_CMD_CONTEXT_DEF_ABRT  "Context definiton aborted."
+#define STRING_CMD_CONTEXT_DEF_ABRT2 "Filter validation failed: {1}"
 #define STRING_CMD_CONTEXT_DEF_CONF  "The filter '{1}' matches 0 pending tasks. Do you wish to continue?"
 #define STRING_CMD_CONTEXT_DEL_SUCC  "Context '{1}' deleted."
 #define STRING_CMD_CONTEXT_DEL_FAIL  "Context '{1}' not deleted."
@@ -707,8 +699,6 @@
 
 #define STRING_EDIT_PROJECT_MOD      "Projet modifié."
 #define STRING_EDIT_PROJECT_DEL      "Projet supprimé."
-#define STRING_EDIT_PRIORITY_MOD     "Priorité modifiée."
-#define STRING_EDIT_PRIORITY_DEL     "Priorité supprimée."
 #define STRING_EDIT_DESC_MOD         "Description modifiée."
 #define STRING_EDIT_DESC_REMOVE_ERR  "Impossible de supprimer la description."
 #define STRING_EDIT_ENTRY_REMOVE_ERR "Impossible de supprimer la date de création."
@@ -873,7 +863,6 @@
 #define STRING_TASK_VALID_BEFORE     "Warning: You have specified that the '{1}' date is after the '{2}' date."
 #define STRING_TASK_VALID_REC_DUE    "A recurring task must also have a 'due' date."
 #define STRING_TASK_VALID_RECUR      "The recurrence value '{1}' is not valid."
-#define STRING_TASK_VALID_PRIORITY   "Priority values may be 'H', 'M' or 'L', not '{1}'."
 #define STRING_TASK_SAFETY_VALVE     "This command has no filter, and will modify all tasks.  Are you sure?"
 #define STRING_TASK_SAFETY_FAIL      "Command prevented from running."
 #define STRING_TASK_SAFETY_ALLOW     "You did not specify a filter, and with the 'allow.empty.filter' value, no action is taken."
@@ -1025,4 +1014,7 @@
 #define STRING_UTIL_KIBIBYTES        "kio"
 #define STRING_UTIL_BYTES            "o"
 
+// Legacy
+#define STRING_LEGACY_PRIORITY       "Legacy attribute found.  Please change '{1}' to '{2}'."
+
 #endif
