@@ -32,7 +32,6 @@
 #include <vector>
 #include <string>
 #include <strings.h>
-#include <ctype.h>
 #include <Context.h>
 #include <Lexer.h>
 #include <math.h>
@@ -351,7 +350,7 @@ std::string commify (const std::string& data)
   int i;
   for (int i = 0; i < (int) data.length (); ++i)
   {
-    if (isdigit (data[i]))
+    if (Lexer::isDigit (data[i]))
       end = i;
 
     if (data[i] == '.')
@@ -369,11 +368,11 @@ std::string commify (const std::string& data)
     int consecutiveDigits = 0;
     for (; i >= 0; --i)
     {
-      if (isdigit (data[i]))
+      if (Lexer::isDigit (data[i]))
       {
         result += data[i];
 
-        if (++consecutiveDigits == 3 && i && isdigit (data[i - 1]))
+        if (++consecutiveDigits == 3 && i && Lexer::isDigit (data[i - 1]))
         {
           result += ',';
           consecutiveDigits = 0;
@@ -393,11 +392,11 @@ std::string commify (const std::string& data)
     int consecutiveDigits = 0;
     for (; i >= 0; --i)
     {
-      if (isdigit (data[i]))
+      if (Lexer::isDigit (data[i]))
       {
         result += data[i];
 
-        if (++consecutiveDigits == 3 && i && isdigit (data[i - 1]))
+        if (++consecutiveDigits == 3 && i && Lexer::isDigit (data[i - 1]))
         {
           result += ',';
           consecutiveDigits = 0;
@@ -473,49 +472,12 @@ bool nontrivial (const std::string& input)
   std::string::size_type i = 0;
   int character;
   while ((character = utf8_next_char (input, i)))
-    if (! Lexer::is_ws (character))
+    if (! Lexer::isWhitespace (character))
       return true;
 
   return false;
 }
 
-////////////////////////////////////////////////////////////////////////////////
-bool digitsOnly (const std::string& input)
-{
-  for (size_t i = 0; i < input.length (); ++i)
-    if (!isdigit (input[i]))
-      return false;
-
-  return true;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-bool noSpaces (const std::string& input)
-{
-  std::string::size_type i = 0;
-  int character;
-  while ((character = utf8_next_char (input, i)))
-    if (Lexer::is_ws (character))
-      return false;
-
-  return true;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-// Override of ispunct, that considers #, $ and @ not to be punctuation.
-//
-// ispunct:      ! " # $ % & ' ( ) * + , - . / : ; < = > ? @ [ \ ] ^ _ ` { | } ~
-// Punctuation:  ! "     % & ' ( ) * + , - . / : ; < = > ?   [ \ ] ^ _ ` { | } ~
-// delta:            # $                                   @
-//
-bool isPunctuation (char c)
-{
-  if (c == '@' || c == '#' || c == '$')
-    return false;
-
-  return ispunct (c);
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 bool compare (
   const std::string& left,
@@ -662,6 +624,38 @@ int strippedLength (const std::string& input)
   return count;
 }
 
+////////////////////////////////////////////////////////////////////////////////
+const std::string obfuscateText (const std::string& input)
+{
+  std::stringstream output;
+  std::string::size_type i = 0;
+  int character;
+  bool inside = false;
+
+  while ((character = utf8_next_char (input, i)))
+  {
+    if (inside)
+    {
+      output << (char) character;
+
+      if (character == 'm')
+        inside = false;
+    }
+    else
+    {
+      if (character == 033)
+        inside = true;
+
+      if (inside || character == ' ')
+        output << (char) character;
+      else
+        output << 'x';
+    }
+  }
+
+  return output.str ();
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 const std::string format (char value)
 {
@@ -978,7 +972,7 @@ std::string rightJustify (const int input, const int width)
 std::string rightJustify (const std::string& input, const int width)
 {
   unsigned int len = utf8_text_width (input);
-  return ((width > len)
+  return (((unsigned int) width > len)
            ? std::string (width - len, ' ')
            : "")
          + input;
