@@ -50,14 +50,12 @@ const std::string str_replace (std::string&, const std::string&, const std::stri
 const std::string str_replace (const std::string&, const std::string&, const std::string&);
 const char* optionalBlankLine ();
 bool nontrivial (const std::string&);
-bool digitsOnly (const std::string&);
-bool noSpaces (const std::string&);
-bool isPunctuation (char);
 bool compare (const std::string&, const std::string&, bool sensitive = true);
 bool closeEnough (const std::string&, const std::string&, unsigned int minLength = 0);
 std::string::size_type find (const std::string&, const std::string&, bool sensitive = true);
 std::string::size_type find (const std::string&, const std::string&, std::string::size_type, bool sensitive = true);
 int strippedLength (const std::string&);
+const std::string obfuscateText (const std::string&);
 const std::string format (char);
 const std::string format (int);
 const std::string formatHex (int);
@@ -86,7 +84,5 @@ std::string rightJustifyZero (const int, const int);
 std::string rightJustify (const int, const int);
 std::string rightJustify (const std::string&, const int);
 
-int mk_wcwidth (wchar_t);
-
 #endif
 ////////////////////////////////////////////////////////////////////////////////
